import { Form } from "antd";
import StaffSelect from "../../staff/staff-select";
import { useDaily } from "../DailyContext";
import { useEffect, useState } from "react";
import { staffDetailSelect, UserProfile } from "@nice/common";
import { api } from "@nice/client";
import { MonitorOutlined } from "@ant-design/icons";

export function DailyMsgFormLayout() {
    const [form] = Form.useForm()
    const { staffsMsg ,selectedUserMsg,setSelectedUserMsg} = useDaily()
    const [selectedUserId, setSelectedUserId] = useState<string | null>(null);
    const { data: selectedUserData } = api.staff.findUnique.useQuery(
        {
            where: {
                id: selectedUserId,
            },
            select: staffDetailSelect
        },
        {
            enabled: !!selectedUserId, // 只有当selectedUserId存在时才执行查询
        }
    );
    const handleChange = (value: string | string[]) => {
        if (!value) {
            setSelectedUserId(null);
            setSelectedUserMsg(null);
            return;
        }
        setSelectedUserId(Array.isArray(value) ? value[0] : value);
    }
    useEffect(() => {
        if (selectedUserData) {
            console.log(selectedUserData)
            setSelectedUserMsg(selectedUserData as any as UserProfile);
        }
    }, [selectedUserData]);

    return (
        <div className="w-full h-[260px] bg-white flex flex-col items-center">
            <Form
                form={form}
            >
                <div className="flex items-center m-8">
                    <MonitorOutlined className="mr-2" />
                    <StaffSelect
                        staffsMsg={staffsMsg}
                        placeholder="请搜索或选择人员"
                        onChange={(value) => handleChange(value)}
                    ></StaffSelect>
                </div>
            </Form>
        </div>
    )
}